==> zscaler_sdk_python-1.2.2.tar.gz: zscaler_sdk_python-1.2.2/zscaler/zpa/models/cbi_certificate.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.oneapi_object import ZscalerObject


class CBICertificate(ZscalerObject):
    """
    A class representing a Cloud Browser Isolation Certificate object.
    """

    def __init__(self, config=None):
        """
        Initialize the CBICertificate model based on API response.

        Args:
            config (dict): A dictionary representing the cloud browser isolation certificate.
        """
        super().__init__(config)

        self.id = config["id"] if config and "id" in config else None
        self.name = config["name"] if config and "name" in config else None
        self.is_default = config["isDefault"] if config and "isDefault" in config else False

    def request_format(self):
        """
        Prepare the object in a format suitable for sending as a request payload.

        Returns:
            dict: A dictionary representing the CBICertificate for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {"id": self.id, "name": self.name, "isDefault": self.is_default}
        parent_req_format.update(current_obj_format)
        return parent_req_format

==> zscaler_sdk_python-1.5.2.tar.gz: zscaler_sdk_python-1.5.2/zscaler/zpa/models/cbi_certificate.py <==
"""
Copyright (c) 2023, Zscaler Inc.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
"""

from zscaler.oneapi_object import ZscalerObject


class CBICertificate(ZscalerObject):
    """
    A class representing a Cloud Browser Isolation Certificate object.
    """

    def __init__(self, config=None):
        """
        Initialize the CBICertificate model based on API response.

        Args:
            config (dict): A dictionary representing the cloud browser isolation certificate.
        """
        super().__init__(config)

        self.id = config["id"] if config and "id" in config else None
        self.name = config["name"] if config and "name" in config else None
        self.pem = config["pem"] if config and "pem" in config else None
        self.is_default = config["isDefault"] if config and "isDefault" in config else False

    def request_format(self):
        """
        Prepare the object in a format suitable for sending as a request payload.

        Returns:
            dict: A dictionary representing the CBICertificate for API requests.
        """
        parent_req_format = super().request_format()
        current_obj_format = {
            "id": self.id,
            "name": self.name,
            "pem": self.pem,
            "isDefault": self.is_default
        }
        parent_req_format.update(current_obj_format)
        return parent_req_format
